window.Gleam.initSearch([{"doc":"bath","title":"bath","content":"# 🛁 Bath\n\n[![Package Version](https://img.shields.io/hexpm/v/bath)](https://hex.pm/packages/bath)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/bath/)\n\nBath is a generic resource pool for Gleam. It can be used to manage a pool of\nany value, such as database connections, file handles, or other resources.\n\n## Installation\n\n```sh\ngleam add bath@1\n```\n\n## Usage\n\n```gleam\nimport bath\nimport fake_db\n\npub fn main() {\n  // Create a pool of 10 connections to some fictional database.\n  let assert Ok(pool) = bath.init(10, fn() { fake_db.connect() })\n\n  // Use the pool. Shown here in a block to use `use`.\n  let assert Ok(&quot;Hello!&quot;) = {\n    use conn &lt;- bath.apply(pool, 1000)\n    // Do stuff with the connection...\n    &quot;Hello!&quot;\n  }\n\n  // Close the pool.\n  let assert Ok(_) = bath.shutdown(pool, fn(conn) { fake_db.close(conn) }, 1000)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/bath&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"bath","title":"ApplyError","content":"pub type ApplyError {\n  NoResourcesAvailable\n  CheckoutTimeout\n}\n An error returned when failing to apply a function to a pooled resource.\nNoResourcesAvailable\n There are no resources available in the pool.\n\nCheckoutTimeout\n The checkout timeout expired.\n\nSynonyms:\nbath.ApplyError\nbath ApplyError","url":"bath.html#ApplyError"},{"doc":"bath","title":"InitError","content":"pub type InitError(resource_create_error) {\n  StartError(actor.StartError)\n  ResourceCreateError(resource_create_error)\n}\n An error returned when creating a [`Pool`](#Pool).\nStartError(actor.StartError)\n The actor failed to start.\n\nResourceCreateError(resource_create_error)\n The resource creation function failed.\n\nSynonyms:\nbath.InitError\nbath InitError","url":"bath.html#InitError"},{"doc":"bath","title":"Pool","content":"pub opaque type Pool(resource_type)\n A resource pool.\n\nSynonyms:\nbath.Pool\nbath Pool","url":"bath.html#Pool"},{"doc":"bath","title":"ShutdownError","content":"pub type ShutdownError {\n  ResourcesInUse\n  ShutdownTimeout\n  CalleeDown(reason: dynamic.Dynamic)\n}\n An error returned when the resource pool fails to shut down.\nResourcesInUse\n There are still resources checked out. Ignore this failure case by\n calling [`force_shutdown`](#force_shutdown) function.\n\nShutdownTimeout\n The shutdown timeout expired.\n\nCalleeDown(reason: dynamic.Dynamic)\n The pool was already down or failed to send the response message.\n\nSynonyms:\nbath.ShutdownError\nbath ShutdownError","url":"bath.html#ShutdownError"},{"doc":"bath","title":"apply","content":"pub fn apply(\n  pool: Pool(a),\n  timeout: Int,\n  next: fn(a) -&gt; b,\n) -&gt; Result(b, ApplyError)\n Check out a resource from the pool, apply the `next` function, then check\n the resource back in.\n\n \n let assert Ok(pool) = bath.init(10, fn() { Ok(&quot;Some pooled resource&quot;) })\n\n use resource &lt;- bath.apply(pool, 1000)\n // Do stuff with resource...\n \nSynonyms:\nbath.apply\nbath apply","url":"bath.html#apply"},{"doc":"bath","title":"force_shutdown","content":"pub fn force_shutdown(\n  pool: Pool(a),\n  resource_shutdown_function: fn(a) -&gt; Nil,\n) -&gt; Nil\n Shut down the pool, calling the `resource_shutdown_function` on each\n resource in the pool.\n\n Will not fail, even if resources are checked out, and will call the\n `resource_shutdown_function` on both checked in and checked out resources.\nSynonyms:\nbath.force_shutdown\nbath force_shutdown","url":"bath.html#force_shutdown"},{"doc":"bath","title":"init","content":"pub fn init(\n  size: Int,\n  resource_create_function: fn() -&gt; Result(a, b),\n) -&gt; Result(Pool(a), InitError(b))\n Start a new resource pool.\n\n \n // Creates a pool with 10 strings.\n let assert Ok(pool) = bath.init(10, fn() { Ok(&quot;Some pooled resource&quot;) })\n \nSynonyms:\nbath.init\nbath init","url":"bath.html#init"},{"doc":"bath","title":"shutdown","content":"pub fn shutdown(\n  pool: Pool(a),\n  resource_shutdown_function: fn(a) -&gt; Nil,\n  timeout: Int,\n) -&gt; Result(Nil, ShutdownError)\n Shut down the pool, calling the `resource_shutdown_function` on each\n resource in the pool.\n\n Will fail if there are still resources checked out.\nSynonyms:\nbath.shutdown\nbath shutdown","url":"bath.html#shutdown"},{"doc":"bath","title":"bath","content":"","url":"bath.html"}]);